atomate.feff.fireworks package — atomate 0.9.2 documentation

# atomate.feff.fireworks package

## Subpackages

- atomate.feff.fireworks.tests package
  - Submodules
  - atomate.feff.fireworks.tests.test_fireworks module
  - Module contents

## Submodules

## atomate.feff.fireworks.core module

class `atomate.feff.fireworks.core.` `EELSFW`(absorbing_atom, structure, feff_input_set='ELNES', edge='K', radius=10.0, name='EELS spectroscopy', beam_energy=100, beam_direction=None, collection_angle=1, convergence_angle=1, user_eels_settings=None, feff_cmd='feff', override_default_feff_params=None, db_file=None, parents=None, metadata=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(absorbing_atom, structure, feff_input_set='ELNES', edge='K', radius=10.0, name='EELS spectroscopy', beam_energy=100, beam_direction=None, collection_angle=1, convergence_angle=1, user_eels_settings=None, feff_cmd='feff', override_default_feff_params=None, db_file=None, parents=None, metadata=None, **kwargs)

    Write the input set for FEFF-EELSS spectroscopy, run feff and insert the core-loss spectrum to the database(or dump to a json file if db_file=None).

    Args:

      absorbing_atom (str): absorbing atom symbol structure (Structure): input structure feff_input_set (str or FeffDictSet subclass): The inputset for setting params. If string

      > then the entire path to the class or the spectrum type must be provide e.g. “pymatgen.io.feff.sets.MPELNESSet” or “ELNES”

      edge (str): absorption edge radius (float): cluster radius in angstroms name (str) beam_energy (float): Incident beam energy in keV beam_direction (list): Incident beam direction. If None, the cross section will be averaged. collection_angle (float): Detector collection angle in mrad. convergence_angle (float): Beam convergence angle in mrad. user_eels_settings (dict): override default EELS config. See MPELNESSet.yaml for supported keys. feff_cmd (str): path to the feff binary override_default_feff_params (dict): override feff tag settings. db_file (str): path to the db file. parents (Firework): Parents of this particular Firework. FW or list of FWS. metadata (dict): meta data **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.feff.fireworks.core.` `EXAFSPathsFW`(absorbing_atom, structure, paths, degeneracies=None, edge='K', radius=10.0, name='EXAFS Paths', feff_input_set='pymatgen.io.feff.sets.MPEXAFSSet', feff_cmd='feff', override_default_feff_params=None, parents=None, filepad_file=None, labels=None, metadata=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(absorbing_atom, structure, paths, degeneracies=None, edge='K', radius=10.0, name='EXAFS Paths', feff_input_set='pymatgen.io.feff.sets.MPEXAFSSet', feff_cmd='feff', override_default_feff_params=None, parents=None, filepad_file=None, labels=None, metadata=None, **kwargs)

    Write the input set for FEFF-EXAFS spectroscopy with customized scattering paths, run feff, and insert the scattering amplitude output files(feffNNNN.dat files) to filepad.

    Args:

      absorbing_atom (str): absorbing atom symbol structure (Structure): input structure paths (list): list of paths. A path = list of site indices that defines the path legs. degeneracies (list): degeneracy of each path. edge (str): absorption edge radius (float): cluster radius in angstroms name (str) feff_input_set (FeffDictSet) feff_cmd (str): path to the feff binary override_default_feff_params (dict): override feff tag settings. parents (Firework): Parents of this particular Firework. FW or list of FWS. filepad_file (str): path to the filepad config file. labels (list): list of label used to tag the files inserted into filepad. metadata (dict): meta data **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.feff.fireworks.core.` `XASFW`(absorbing_atom, structure, feff_input_set='XANES', edge='K', radius=10.0, name='XAS spectroscopy', feff_cmd='feff', override_default_feff_params=None, db_file=None, parents=None, metadata=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(absorbing_atom, structure, feff_input_set='XANES', edge='K', radius=10.0, name='XAS spectroscopy', feff_cmd='feff', override_default_feff_params=None, db_file=None, parents=None, metadata=None, **kwargs)

    Write the input set for FEFF-XAS spectroscopy, run FEFF and insert the absorption coefficient to the database (or dump to a json file if db_file=None).

    Args:

      absorbing_atom (str): absorbing atom symbol structure (Structure): input structure feff_input_set (str or FeffDictSet subclass): The inputset for setting params. If string

      > then either the entire path to the class or spectrum type must be provided e.g. “pymatgen.io.feff.sets.MPXANESSet” or “XANES”

      edge (str): absorption edge radius (float): cluster radius in angstroms name (str) feff_cmd (str): path to the feff binary override_default_feff_params (dict): override feff tag settings. db_file (str): path to the db file. parents (Firework): Parents of this particular Firework. FW or list of FWS. metadata (dict): meta data **kwargs: Other kwargs that are passed to Firework.__init__.

## Module contents